# Automate IT operations

Using this library you can define automation task trough YAML file.
It already includes some AWS tasks. Here is a list of some of these tasks...
* Register target in a target group
* De register target from target group
* Reboot EC2 instance
* Check ECS services count (desired against running tasks)
* Change ECS Task Definition container image
* Update Task Definition revision for ECS Service 